
# Type: affects risk for


holds between two entities where exposure to one entity alters the chance of developing the other

URI: [biolink:affects_risk_for](https://w3id.org/biolink/vocab/affects_risk_for)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [predisposes](predisposes.md)
 *  [prevents](prevents.md)

## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |

